#!/usr/bin/env python3

from matplotlib import pyplot as pt
from numpy import *
import sys
from optparse import OptionParser
import pNbody as pn


def parse_options():
    usage = "usage: %prog [options] file"
    parser = OptionParser(usage=usage)

    parser.add_option("--relative",
                      action="store_true",
                      dest="relative",
                      default=False,
                      help="plot relative energy")

    parser.add_option("-o",
                      action="store",
                      dest="obs",
                      type="string",
                      default='E',
                      help="observable name")

    (options, args) = parser.parse_args()

    if len(args) == 0:
        print("you must specify a filename")
        sys.exit(0)

    file = args[0]

    return file, options


#################################
# main
#################################


# get options
file, options = parse_options()
relative = options.relative
obs = options.obs

vals = pn.iofunc.read_ascii(file)

x = vals['t']

if obs in vals:
    y = vals[obs]

elif obs == 'virial':

    y = -2 * vals["T"] / vals["U"]

elif obs == 'I':
    y = vals["Ix"] + vals["Iy"] + vals["Iz"]

else:
    print("unknown observable %s" % (obs))
    sys.exit()

if relative:
    y = 100 * (fabs(y - y[0])) / y[0]
    y = fabs(y)

pt.plot(x, y)

#  xmin, xmax, ymin, ymax = pt.SetLimits(None, None, None, None, x, y)
#  pt.axis([xmin, xmax, ymin, ymax])

pt.xlabel('Time')
pt.ylabel(obs)

#  pt.show()
pt.savefig("integrals.png")
